import { Component, OnInit } from '@angular/core';
import { HttpClient } from '@angular/common/http';

@Component({
  selector: 'app-task-logs',
  templateUrl: './task-logs.component.html',
  styleUrls: ['./task-logs.component.css']
})
export class TaskLogsComponent implements OnInit {

  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  traces: any[] = [];
  groupedTraces: any[] = [];
  length: number = 0;
  itemsPerPage: number = 20;
  page: number = 1;
  pageSizeOptions: number[] = [10, 20, 30, 50];
  displayedColumns: string[] = ['commandId','commandName', 'clientName', 'status', 'executedAt', 'createdBy'];

  searchCommand: string = '';
  searchClient: string = '';
  searchStatus: string = '';
  searchCreatedBy: string = '';
  searchExecutedAt: string = '';

  constructor(private http: HttpClient) {}

  ngOnInit(): void {
    this.loadTraces();
  }

  loadTraces(): void {
    const url = `${this.baseUrl}/traces?page=${this.page}&itemsPerPage=${this.itemsPerPage}`;
    
    this.http.get<any>(url).subscribe(
      (data) => {
        this.traces = data['hydra:member'];
        this.length = data['hydra:totalItems'];
        this.groupedTraces = this.groupByCommandId(this.traces); 
      },
      (error) => {
        console.error('Error fetching traces', error);
      }
    );
  }

  groupByCommandId(traces: any[]): any[] {
    const grouped: { [key: string]: any[] } = {};

    traces.forEach(trace => {
      const commandId = trace.command.id;
      if (!grouped[commandId]) {
        grouped[commandId] = [];
      }
      grouped[commandId].push(trace);
    });

    return Object.keys(grouped).map(key => ({
      commandId: key,
      traces: grouped[key]
    }));
  }

  onPageChange(event: any): void {
    this.page = event.pageIndex + 1; 
    this.itemsPerPage = event.pageSize; 
    this.loadTraces(); 
  }

  filterTraces(): void {
    const filtered = this.traces.filter(trace => {
      const commandMatch = trace.command.name.toLowerCase().includes(this.searchCommand.toLowerCase());
      const clientMatch = trace.client.name.toLowerCase().includes(this.searchClient.toLowerCase());
      const statusMatch = trace.status.toLowerCase().includes(this.searchStatus.toLowerCase());
      const createdByMatch = trace.createdBy.toLowerCase().includes(this.searchCreatedBy.toLowerCase());
      const executedAtMatch = trace.executedAt.toLowerCase().includes(this.searchExecutedAt.toLowerCase());
      
      return commandMatch && clientMatch && statusMatch && createdByMatch && executedAtMatch;
    });

    this.length = filtered.length; 
    this.groupedTraces = this.groupByCommandId(filtered); 
  }
}
